@@ -6,16 +6,24 @@ use Carp                   qw/croak/;
 use Config::AutoConf 0.313 qw//;
 use Config::Tiny::Ordered  qw//;
 use File::Basename         qw/fileparse/;
-use File::Path             qw/make_path/;
+use File::Path             qw//;
 use Scalar::Util           qw/looks_like_number blessed/;
 use parent                 qw/Config::AutoConf/;
 
 # ABSTRACT: Drive Config::AutoConf with an INI file
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
+our $_make_path;
+BEGIN {
+    #
+    # Old versions of File::Path does not provide make_path, but the legacy mkpath
+    #
+    $_make_path = File::Path->can('make_path') || File::Path->can('mkpath');
+}
+
 
 sub check {
     my ($self, $config_ini) = @_;
@@ -104,7 +112,7 @@ sub _write_config_h {
     #
     my ($filename, $dirs, $suffix) = fileparse($path);
     if ($dirs) {
-        make_path($dirs); # This will croak in case of failure
+        &$_make_path($dirs); # This will croak in case of failure
     }
     $self->write_config_h($path);
 }
@@ -243,7 +251,7 @@ Config::AutoConf::INI - Drive Config::AutoConf with an INI file
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
